.BG
.FN nolr
.TL
Nonlinear Ordinal Logistic Regression (NOLR)
.DN
Fits nonlinear ordinal logistic regression models using a neural network.
.CS
nolr(x, y, size, weights, Wts, skip=T, riskfit=F, loss=0,
phi, decay=0, cutreg=F, thetamean=5, thetavar=2, rang=1,
trace=T, maxit=1000, maxitb=0, mask)
.RA
.AG x
Matrix or data frame, the rows of which are the x values for the examples.
.AG y
Vector of class numbers corresponding to the examples in the rows of
`x'. The classes must be numbered consecutively 1,2,... If simple class
censoring is required, then `y' can be a matrix with two columns. The
first column gives the lowest possible class for each observation, and
the second column gives the highest possible class for each
observation.
.AG size
Number of units in the hidden layer. With `skip=T' and `size=0' a linear OLR model is fitted.
.OA
.AG weights
Weights for each example. If missing defaults to 1.
.AG Wts
Vector of initial network weights. If missing chosen at random.
.AG skip
Switch to add skip-layer connections from input to output.
.AG riskfit
Switch for fitting by training risk minimization. Default is fitting by maximum likelihood.
.AG loss
Loss matrix (for `riskfit=T').
.AG phi
Vector of initial cutpoints. If missing chosen at random.
.AG decay
Weight decay parameter(s). If a single value is supplied it is used as
the decay for all weights. If a vector of length `length(Wts)' is
supplied, each component specifies the decay for the associated
weight.
.AG cutreg
Switch for cut-point regularization.
.AG thetamean
Mean for cut-point regularization (for `cutreg=T').
.AG thetavar
Variance for cut-point regularization (for `cutreg=T').
.AG rang
Initial random weights on `[-rang, rang]'.
.AG trace
Switch for tracing optimization.
.AG maxit
Maximum number of iterations. Default 1000.
.AG maxitb
Maximum number of iterations optimizing the network weights, holding
cut-points fixed. Default 0.
.AG mask
Mask for weights to be held fixed during optimization.
.RT
Object of class `"nolr"'. Components include:
.RC wts
Fitted network weights.
.RC phi
Fitted cutpoints.
.RC E
Value of the fitting criterion.
.DT
A BFGS quasi-Newton optimizer is used.
.SH REFERENCES
For OLR: 
.br
McCullagh, P. (1980) Regression models for ordinal
data. 
.ul
Journal of the Royal Statistical Society Series B,
\fB42\fR,109-142.
.PP
For NOLR:
.br
Mathieson, M.J. (1995) Ordinal models for
neural networks. In 
.ul
`Neural Networks in Financial Engineering',
eds A.-P. Refenes, Y. Abu-Mostafa, J. Moody and A. Weigend 
(World Scientific, Singapore) 523-536.
.br
or similar material from URL

`http://www.stats.ox.ac.uk/~mathies'
.PP
Future releases of this library and further information will be posted at this location.
.SA
`predict.nolr', `Hess.nolr'. 
.EX
An example is given in the postscript file example.ps

# Fit nolr to synthetic dataset with 4 ordered classes
plot(x.train$x1, x.train$x2, type="n", xlab="x1", ylab="x2")
text(x.train$x1, x.train$x2, y.train)
	# plot training set
net <- nolr(x.train,y.train,size=3,decay=0.1)
	# fit network
eigen(Hess.nolr(net,x.train,y.train), T)$values
	# check for genuine local optimum
	# is Hessian positive definite?
summary(net)
predict(net,x.test,type="probs")
	# matrix of posterior class probabilities
	# for test set

# Visualize the fitted model
grid <- list(x=seq(-5,5,0.2),y=seq(-6,6,0.2))
pred <- matrix(predict(net,expand.grid(grid),type="predictor"),
       		length(grid$x))
par(mfrow=c(1,2),pty="s")
image(grid$x, grid$y, pred, xlab="x1", ylab="x2")
text(x.train$x1, x.train$x2, y.train)
persp(grid$x, grid$y, pred, xlab="x1", ylab="x2",
       zlab="eta(x) (Net output)")

.KW nolr
.WR
